# Demo Email Agent

AIAI CLI includes a built-in demo email agent that showcases how the tool optimizes AI workflows. This demo is directly integrated into the AIAI CLI tool for easy access.

## What This Demo Does

The demo is an outbound email agent built with CrewAI that:

- Creates personalized sales emails for potential leads
- Analyzes lead information (role, company, pain points)
- Crafts persuasive content highlighting relevant product benefits
- Demonstrates real-world AI agent optimization opportunities

## Running the Demo

Running the demo is simple:

```bash
# Run AIAI CLI
aiai

# Select option 1 when prompted: "Outbound email agent (Demo)"
```

The CLI will guide you through the optimization process:

1. **Code Analysis**: AIAI analyzes the agent's code structure
2. **Evaluation Criteria**: The tool generates criteria to assess email quality
3. **Synthetic Data**: Test examples are created to evaluate the agent
4. **Optimization**: Rules and improvements are identified
5. **Report Generation**: A detailed optimization report is saved to your current directory

## What You'll Learn

This demo helps you understand:

- How AIAI CLI analyzes and optimizes AI agent code
- Effective patterns for email personalization
- Common optimization opportunities in AI workflows
- The complete AIAI optimization pipeline

## More Examples

For additional examples using different frameworks, check out the [AIAI CLI Examples Repository](https://github.com/zenbase-ai/aiai-cli-examples), which includes implementations with both CrewAI and LangGraph.

## What These Demos Do

The example agents generate personalized sales emails based on lead information. They demonstrate:

- How to structure AI agents for email generation tasks
- Effective prompt engineering patterns for personalization
- Different implementation approaches (CrewAI and LangGraph)

## Try It Yourself

To explore these examples:

```bash
git clone https://github.com/zenbase-ai/aiai-cli-examples.git
cd aiai-cli-examples
```

For complete setup instructions and code examples, visit the [AIAI CLI Examples Repository](https://github.com/zenbase-ai/aiai-cli-examples).

## What AIAI CLI Will Optimize

When you run these examples through AIAI CLI, it will identify optimization opportunities such as:

- Improved prompt engineering patterns
- Better handling of lead information
- More effective email personalization strategies

These examples serve as practical demonstrations of how AIAI CLI can help optimize AI agent workflows in real-world scenarios.

## Email Agent Implementations

The AIAI CLI examples repository includes two implementations of email generation agents:

### 1. CrewAI Email Agent

The CrewAI implementation is a specialized agent that:

- Creates personalized sales emails for potential leads
- Highlights how Zenbase can address specific customer needs
- Focuses on LLM development, prompt engineering, and model optimization capabilities
- Uses CrewAI's agent and task framework for structured workflow

### 2. LangGraph Email Agent

The LangGraph implementation offers a more complex multi-step workflow that:

- Extracts structured lead information from unstructured text
- Processes multiple leads simultaneously
- Generates tailored emails for each lead
- Uses a directed graph approach with distinct processing nodes
